# SCIM Provisioning
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/scim-provisioning#introduction)
  * [Synchronized Attributes](https://help.sap.com/docs/leanix/ea/scim-provisioning#synchronized-attributes)
  * [Limitations](https://help.sap.com/docs/leanix/ea/scim-provisioning#limitations)
  * [Configuring SCIM](https://help.sap.com/docs/leanix/ea/scim-provisioning#configuring-scim)
  * [SCIM Attribute Mapping](https://help.sap.com/docs/leanix/ea/scim-provisioning#scim-attribute-mapping)


Learn how to configure System for Cross-Domain Identity Management (SCIM) for seamless user state synchronization.
